@@ -1,23 +1,28 @@
-from django import forms
-from django.utils import simplejson as json
-from django.db.models.fields.subclassing import Creator
-from django.db.models import TextField
-from django.utils.encoding import smart_unicode
+import json
 
-from south.modelsinspector import add_introspection_rules
+import six
+
+from django import forms
+from django.db.models import TextField
+from django.utils.encoding import smart_text
 
 from .registry import app_registry
 from .containers import AppDataContainerFactory
 
-class AppDataDescriptor(Creator):
-    "Ensure the user attribute is accessible via the profile"
+
+class AppDataDescriptor(object):
+    """Ensure the user attribute is accessible via the profile"""
+
+    def __init__(self, field):
+        self.field = field
+
     def __get__(self, instance, instance_type=None):
         if instance is None:
             return self
 
         value = instance.__dict__[self.field.name]
 
-        if isinstance(value, basestring):
+        if isinstance(value, six.string_types):
             value = json.loads(value)
 
         if isinstance(value, dict) and not isinstance(value, AppDataContainerFactory):
@@ -33,7 +38,7 @@ class AppDataDescriptor(Creator):
         if instance is None:
             raise AttributeError("%s must be accessed via instance" % self.field.name)
         if isinstance(value, dict) and not isinstance(value, AppDataContainerFactory):
-            value = AppDataContainerFactory(instance, value)
+            value = AppDataContainerFactory(instance, value, app_registry=self.field.app_registry)
         instance.__dict__[self.field.name] = value
 
 
@@ -44,8 +49,8 @@ class AppDataField(TextField):
         kwargs.setdefault('editable', False)
         super(AppDataField, self).__init__(*args, **kwargs)
 
-    def contribute_to_class(self, cls, name):
-        super(AppDataField, self).contribute_to_class(cls, name)
+    def contribute_to_class(self, cls, name, **kwargs):
+        super(AppDataField, self).contribute_to_class(cls, name, **kwargs)
         setattr(cls, name, AppDataDescriptor(self))
 
     def get_db_prep_value(self, value, connection, prepared=False):
@@ -61,14 +66,14 @@ class AppDataField(TextField):
         value.validate(model_instance)
 
     def value_to_string(self, obj):
-        value = self._get_val_from_obj(obj)
+        value = self.value_from_object(obj)
 
         if isinstance(value, AppDataContainerFactory):
             value = value.serialize()
         if isinstance(value, dict):
             value = json.dumps(value)
 
-        return smart_unicode(value)
+        return smart_text(value)
 
 
 class ListModelMultipleChoiceField(forms.ModelMultipleChoiceField):
@@ -80,6 +85,4 @@ class ListModelMultipleChoiceField(forms.ModelMultipleChoiceField):
     """
     def clean(self, value):
         value = super(ListModelMultipleChoiceField, self).clean(value)
-        return value and list(value) or value
-
-add_introspection_rules([], ["^app_data\.fields\.AppDataField"])
+        return list(value)
